from fastapi import APIRouter, BackgroundTasks, Depends, Response
from sqlalchemy.orm import Session

from src.api.cruds import chat as notif_crud
from src.api.cruds import subscription as sub_crud
from src.api.db import get_db
from src.api.schemas.subscription import FlightData
from src.api.utils import telegram
from src.api.utils.messages import get_update_message

router = APIRouter()


@router.post("")
async def send_notification(
    flight: FlightData, background_tasks: BackgroundTasks, db: Session = Depends(get_db)
):
    db_subscriptions = sub_crud.send_subscriptions(db=db, flight=flight)
    for subscription in db_subscriptions:
        db_chat = notif_crud.get_chat_id(db=db, user_id=subscription.user_id)
        if db_chat is None:
            continue
        msg = get_update_message(flight)
        print(msg)
        background_tasks.add_task(telegram.send_message, db_chat.chat_id, msg)
    return Response(status_code=204)
